<?php
namespace Teknisa\CDP\Controllers;

use Teknisa\CDP\Controllers\TeknisaCrud;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\ParameterBag;
use \Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request\Row;
use Teknisa\CDP\Services\OpdigitalService;

class OpdigitalController extends TeknisaCrud {

    protected $service; 
    protected $parameterBag;
    protected $entityManager;
    
    public function __construct($crudService, ParameterBag $parameterBag, EntityManager $entityManager, OpdigitalService $service)
    {        
        $this->service = $service;
        $this->entityManager = $entityManager;
        $this->OpdigitalService = $service;
        parent::__construct($crudService, $parameterBag);
    }
    
   
    public function preparaItensRetirada(DTO\Request $request, DTO\Response $response){
        try {   
            
            $row  = $request->getRow();
            
            $result = $this->OpdigitalService->preparaItensRetirada($row);
            
            $response->addDataSet(new DataSet('/result', [$result]));
        
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode())); 
        }
    }
    
    public function preparaFechamento(DTO\Request $request, DTO\Response $response){
        
        try {
            
            $row  = $request->getRow();
            $result = $this->OpdigitalService->preparaFechamento($row);
            
            $response->addDataSet(new DataSet('/result', [$result]));
        
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode())); 
        }
    }
    
    public function atualizaEstoqueRetirada(DTO\Request $request, DTO\Response $response){
        try {   
            $rows = $request->getDataSet()->getRows();
            
            $result = $this->OpdigitalService->atualizaEstoqueRetirada($rows);
            
            $response->addDataSet(new DataSet('arrayErro', $result));
        
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode())); 
        }
    }
    
    public function fechaOp(DTO\Request $request, DTO\Response $response){
        try {   
            $rows = $request->getDataSet()->getRows();
            
            $result = $this->OpdigitalService->fechaOp($rows);
            
            $response->addDataSet(new DataSet('allError', [$result]));
        
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode())); 
        }
    }
    
    public function getParamValidacoes(DTO\Request $request, DTO\Response $response){
        try{
            $rows = $request->getDataSet()->getRows();
            $row = $rows[0];
            $countProdRet = $this->OpdigitalService->getCountProdRet($row);
            $vdEvolEstq = $this->OpdigitalService->getVdEvolEstq($row);
            //$idrecalcinsumo = $this->OpdigitalService->getIdrecalcinsumo($row);
            $paramman = $this->OpdigitalService->getParamman($row);
            $idrecalcinsumo = $paramman['IDRECALCINSUMO'];
            $paramfili = $this->OpdigitalService->getParamfili($row);
            //$insuPrev = $this->OpdigitalService->getInsuPrev($row); aparentemente nao é usado nas validaçoes
            
            $response->addDataSet(new DataSet('countProdRet', $countProdRet));
            $response->addDataSet(new DataSet('vdEvolEstq', $vdEvolEstq));
            $response->addDataSet(new DataSet('idrecalcinsumo', [$idrecalcinsumo]));
            $response->addDataSet(new DataSet('paramfili', $paramfili));
            $response->addDataSet(new DataSet('paramman', $paramman));
            //$response->addDataSet(new DataSet('insuPrev', $insuPrev)); aparentemente nao é usado nas validaçoes
        }catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode())); 
        }
    }
    
    public function validaQtPrevDifMov(DTO\Request $request, DTO\Response $response){
        try{
            $rows = $request->getDataSet()->getRows();
            $row = $rows[0];
            $validacoes = $this->OpdigitalService->validaQtPrevDifMov($rows);
            
            $response->addDataSet(new DataSet('validaQtPrevDifMov', $validacoes));

        }catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode())); 
        }
    }

}
