<?php
namespace Teknisa\CDP\Modules\Producao\Controllers; 

use Zeedhi\Framework\DTO;
use \Setforms2\Shared\ORM\DateTime;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;
use \Teknisa\CDP\Controllers\TeknisaCrud;
use \Doctrine\ORM\EntityManager;

class ger02500NutrienteController extends TeknisaCrud {

    protected $dataSourceName = "nutriente";
    protected $parameterBagColumns = array ("NRORG");
    protected $environment;
	protected $entityManager;

	public function __construct($crudService, ParameterBag $parameterBag, $environment, $entityManager) {
	    parent::__construct($crudService, $parameterBag);
	    $this->environment = $environment;
	    $this->entityManager = $entityManager;
	}

    public function save(DTO\Request $request, DTO\Response $response) {
    	try {
	    	$nextNrordemnutr = $this->getNextNrordemnutr();
	    	$rows = $this->crudService->buildDataSetIfRow($request, $this->dataSourceName)->getDataSet()->getRows() ;
			foreach ($rows as $row => $value) {
				if ($rows[$row]['__is_new']) {
		        	$rows[$row]['NRORDEMNUTR'] = $nextNrordemnutr;
		        	$rows[$row]['DTULTATUNUTR'] = DateTime::createFromFormat('d/m/Y', new DateTime);
		        	$rows[$row]['CDEXPARQTXTVND'] = isset($rows[$row]['CDEXPARQTXTVND']) ? $rows[$row]['CDEXPARQTXTVND'] : null;
		        	$nextNrordemnutr = $nextNrordemnutr + 1;
		        }
			}
			$dataSet = new DataSet($this->dataSourceName, $rows);
			$newRequest = new DTO\Request\DataSet($dataSet, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
	     	parent::save($newRequest, $response);	        	
     	} catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function delete(DTO\Request $request, DTO\Response $response) {
    	try {
    		parent::delete($request, $response);	  
	    	$minNrordemnutr = $this->getMinNrordemnutrDeleted(parent::buildDataSetIfRow($request)->getDataSet()->getRows());
	    	$this->entityManager->getConnection()->beginTransaction();
	    	$registers = $this->getNextRegisters($minNrordemnutr);
	    	if (!empty($registers)) {
		    	foreach ($registers as $row => $value) {
		    		$nutriente = $this->entityManager->getRepository('\Geral\Entities\Nutriente')
		            ->findOneBy(array("cdnutriente" => $registers[$row]['CDNUTRIENTE'], "nrorg" => $registers[$row]['NRORG']));
		            $nutriente->setNrordemnutr($minNrordemnutr);
		            $this->entityManager->persist($nutriente);		
					$this->entityManager->flush();
					$minNrordemnutr = $minNrordemnutr + 1; 
		    	}
	    	}
			$this->entityManager->getConnection()->commit();
		} catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function getNextNrordemnutr() {
    	$query = $this->entityManager->getConnection()->prepare(
    		"SELECT (MAX(NRORDEMNUTR) + 1) AS PROXNRORDEMNUTR 
    			FROM NUTRIENTE WHERE NRORG = :NRORG"
    	);
        $query->execute(array('NRORG' => $this->environment->getNrOrgTrab()));
        return floatval($query->fetchAll()[0]['PROXNRORDEMNUTR']);
    }
 
    public function getMinNrordemnutrDeleted($rows) {
		$minor = $rows[0]['NRORDEMNUTR'];
		foreach ($rows as $row) {
			if (floatval($row['NRORDEMNUTR']) < $minor) {
				$minor = floatval($row['NRORDEMNUTR']);
			}
		} 
		return floatval($minor);   	
    }
    
    public function getNextRegisters($minNrordemnutr) {
    	$query = $this->entityManager->getConnection()->prepare(
    		"SELECT *
          		FROM NUTRIENTE 
          		WHERE NRORG = :NRORG
          		AND NRORDEMNUTR > :NRORDEMNUTR
          		ORDER BY NRORDEMNUTR"
    	);
        $query->execute(array(
        	'NRORG' => $this->environment->getNrOrgTrab(),
        	'NRORDEMNUTR' => $minNrordemnutr
        ));
        return $query->fetchAll();
    }
    
}