<?php
namespace Teknisa\CDP\Modules\Producao\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Cdp07700CalendarioDeProducaoFactory {

    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection       = $entityManager->getConnection();
        $this->entityManager    = $entityManager;
    }

    public function deleteCalendarioProducao($nrorg,$cdfilial,$cdperiprodu,$anodeleta){
        try {
            
            $sql = "DELETE FROM CALEPRODUCAO
                    WHERE NRORG = :NRORG AND
                        CDFILIAL    = :CDFILIAL AND
                        CDPERIPRODU = :CDPERIPRODU AND
                        TO_CHAR(DTPRODUCAO, 'YYYY') =:ANODELETA ";

            $params = array(
                'NRORG'=>$nrorg,
                'CDFILIAL'=>$cdfilial,
                'CDPERIPRODU'=>$cdperiprodu,
                'ANODELETA'=>$anodeleta
            );
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
        }catch (\Exception $e) {
            throw $e;
        }
       
    }
    
    public function deleteCalendarioProducaoMes($nrorg,$cdfilial,$cdperiprodu,$anodeleta){
        try {
            
            $sql = "DELETE FROM CALEPRODUCAO
                    WHERE NRORG = :NRORG AND
                        CDFILIAL    = :CDFILIAL AND
                        CDPERIPRODU = :CDPERIPRODU AND
                        TO_CHAR(DTPRODUCAO, 'MM/YYYY') =:ANODELETA ";

            $params = array(
                'NRORG'=>$nrorg,
                'CDFILIAL'=>$cdfilial,
                'CDPERIPRODU'=>$cdperiprodu,
                'ANODELETA'=>$anodeleta
            );
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
        }catch (\Exception $e) {
            throw $e;
        }
       
    }
    
    public function CalculoProdAnual($rows, $response) {
        
        try {
            $this->connection->beginTransaction();
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'CALCULA_PERIPRODUCAO');
            $procedure->addParam(new Param('P_CDFILIAL'     ,   Param::PARAM_INPUT, $rows['CDFILIAL']         ,   Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDPERIPRODU'    , Param::PARAM_INPUT, $rows['CDPERIPRODU']      ,   Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_DTINICIAL'  ,     Param::PARAM_INPUT, $rows['DTINICIAL']        ,   Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRMESES'  ,       Param::PARAM_INPUT, $rows['NRMESES']          ,   Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_DTPROCESSA'   ,   Param::PARAM_INPUT, $rows['DTPROCESSA']         , Param::PARAM_TYPE_STR));
            $procedure->execute(); //Invoca a procedure para gerar comissão
            var_dump($rows);die;
            $this->connection->commit();
        } catch (\Exception $e) {
            $response->setError(new Error("Error in data save. ". $e->getMessage(), 500));
            $this->entityManager->rollback();
            throw $e;
        }
        
    }
    
}

